using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Security.Principal;
using System.Windows.Forms;
using System.DirectoryServices;
using System.Management;
using Manager.Schemas;
using Manager.Forms;
using System.Globalization;
using System.Security.Permissions;
using System.Threading;

namespace Manager
{
	public class frmAuthorization : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button btnOK;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.TextBox txtUserName;
		private System.Windows.Forms.TextBox txtPassword;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.ComponentModel.Container components = null;
		
		internal enum UserGroup
		{
			ChiefManagers,
			PManagers,
			Recipients,
			FailGroup
		}

		public frmAuthorization()
		{
			InitializeComponent();
			this.InitialDefaultSettings();	
		}


		private void OpenMainForm(UserGroup userGroup, Label label)
		{
			frmManager mainForm = new frmManager();
			
			mainForm.userGroup = userGroup;
			switch (userGroup)
			{
				case UserGroup.ChiefManagers:
					mainForm.panel12.Visible = true;
					mainForm.rbDataMain.Visible = true;
					mainForm.rbIncomeMain.Visible = true;
					mainForm.rbOutMain.Visible = true;
					mainForm.dgWorkTable.ReadOnly = false;
					mainForm.tcManager.SelectedTab = mainForm.tcManager.TabPages[1];
					mainForm.btnShowPaymentTypeForm.Visible = true;
					break;

				case UserGroup.PManagers:						
					mainForm.panel12.Visible = false;
					mainForm.panel16.Dock = DockStyle.Fill;
					mainForm.panel18.Visible = false;
					mainForm.rbDataMain.Visible = false;						
					mainForm.dgOut.Visible = false;
					mainForm.splitter2.Visible = false;
					mainForm.rbIncomeMain.Visible = true;
					mainForm.rbOutMain.Visible = false;
					mainForm.dgWorkTable.ReadOnly = false;
					mainForm.tcManager.SelectedTab = mainForm.tcManager.TabPages[0];
					mainForm.btnShowPaymentTypeForm.Visible = false;
					break;

				case UserGroup.Recipients:						
					mainForm.panel12.Visible = false;
					mainForm.panel16.Dock = DockStyle.Fill;
					mainForm.panel18.Visible = false;
					mainForm.rbDataMain.Visible = false;
					mainForm.dgOut.Visible = false;
					mainForm.splitter2.Visible = false;
					mainForm.rbIncomeMain.Visible = false;
					mainForm.rbOutMain.Visible = false;
					mainForm.dgWorkTable.ReadOnly = false;
					mainForm.tcManager.SelectedTab = mainForm.tcManager.TabPages[0];
					mainForm.gbBaseTables.Anchor = AnchorStyles.Bottom | AnchorStyles.Right;
					mainForm.btnShowPaymentTypeForm.Visible = false;
					break;

				case UserGroup.FailGroup:
					MessageBox.Show("      .\n\n" + 
						"      :\n" + 
						"ChiefManagers, PManagers  Recipients.\n\n" + 
						"      .", "", MessageBoxButtons.OK, MessageBoxIcon.Error);
					System.Environment.Exit(1);			
					break;
			}

			label.Text = "Loading database ...";
			mainForm.LoadMainDataBase();

			label.Text = "Checking data ...";
			mainForm.PasteDateRow();

			label.Text = "Loading ...";
			mainForm.FillPaymentsPage();
			mainForm.Explorer(); 
			mainForm.Show();
			mainForm.CheckEmployeesBirthDays();
			
			label.Text = "Ready";
		}		

		private void CheckLogin()
		{
			try
			{	
				this.Visible = false;
				frmHeadBand headBand = new frmHeadBand();
				headBand.Show();
				headBand.Cursor = Cursors.WaitCursor;
				headBand.label1.Text = "Checking...";
			
				UserGroup userGroup = UserGroup.ChiefManagers;
				DirectoryEntry de=new DirectoryEntry();
				
				try
				{
					de.Path = "LDAP://";
					de.Username = txtUserName.Text;
					de.Password = txtPassword.Text;

					//      ,
					//   if   System.Runtime.InteropServices.COMException
//					if(de.NativeObject == null)
//						MessageBox.Show("Failed");
				}
				catch(System.Runtime.InteropServices.COMException)
				{
//					MessageBox.Show("    ", 
//						"", MessageBoxButtons.OK, MessageBoxIcon.Error);
//				
//					System.Environment.Exit(1);   
				}

				WindowsIdentity wi = WindowsIdentity.GetCurrent();
				WindowsPrincipal wp = new WindowsPrincipal(wi);
				if (wi.Name.ToLower() != de.Username.ToLower())
				{
//					MessageBox.Show("      .\n\n" + 
//						",         .", 
//						"", MessageBoxButtons.OK, MessageBoxIcon.Error);
//	
//					System.Environment.Exit(1);  		
				}
				
				//  								
				if (wp.IsInRole(@"SomeDomain\ChiefManagers")) // ChiefManagers
					userGroup = UserGroup.ChiefManagers;
				
				else if (wp.IsInRole(@"SomeDomain\PManagers")) // PManagers
					userGroup = UserGroup.PManagers;
				
				else if (wp.IsInRole(@"SomeDomain\Recipients")) // Recipients
					userGroup = UserGroup.Recipients;
				
				this.OpenMainForm(userGroup, headBand.label1);
				
				headBand.Dispose();
			}
			catch (Exception ex)
			{		
//				MessageBox.Show(ex.Message, ex.Source);
//				System.Environment.Exit(1);
			}
		}
		private void InitialDefaultSettings()
		{
			this.MinimumSize = this.Size;
			this.MaximumSize = this.Size;
			this.btnCancel.Click += new EventHandler(btnCancel_Click);
			this.StartPosition = FormStartPosition.CenterScreen;
			this.txtUserName.TextChanged += new EventHandler(txtUserName_TextChanged);
			this.txtPassword.TextChanged += new EventHandler(txtPassword_TextChanged);
			this.btnOK.Click += new EventHandler(btnOK_Click);
			this.Activated += new EventHandler(frmAuthorization_Activated);
		}
		
		
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		
		[STAThread]
		private static void Main() 
		{
			Application.Run(new frmAuthorization());
		}

		
		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.btnOK = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.txtUserName = new System.Windows.Forms.TextBox();
			this.txtPassword = new System.Windows.Forms.TextBox();
			this.label1 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.SuspendLayout();
			// 
			// btnOK
			// 
			this.btnOK.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnOK.DialogResult = System.Windows.Forms.DialogResult.OK;
			this.btnOK.Location = new System.Drawing.Point(144, 136);
			this.btnOK.Name = "btnOK";
			this.btnOK.TabIndex = 2;
			this.btnOK.Text = "OK";
			// 
			// btnCancel
			// 
			this.btnCancel.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnCancel.Location = new System.Drawing.Point(224, 136);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 3;
			this.btnCancel.Text = "Cancel";
			// 
			// txtUserName
			// 
			this.txtUserName.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.txtUserName.Location = new System.Drawing.Point(24, 49);
			this.txtUserName.Name = "txtUserName";
			this.txtUserName.Size = new System.Drawing.Size(280, 20);
			this.txtUserName.TabIndex = 0;
			this.txtUserName.Text = "";
			// 
			// txtPassword
			// 
			this.txtPassword.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.txtPassword.Location = new System.Drawing.Point(24, 97);
			this.txtPassword.Name = "txtPassword";
			this.txtPassword.PasswordChar = '*';
			this.txtPassword.Size = new System.Drawing.Size(280, 20);
			this.txtPassword.TabIndex = 1;
			this.txtPassword.Text = "";
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(24, 32);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(100, 16);
			this.label1.TabIndex = 4;
			this.label1.Text = "User name:";
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(24, 80);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(100, 16);
			this.label2.TabIndex = 5;
			this.label2.Text = "Password:";
			// 
			// frmAuthorization
			// 
			this.AcceptButton = this.btnOK;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnCancel;
			this.ClientSize = new System.Drawing.Size(322, 175);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.txtPassword);
			this.Controls.Add(this.txtUserName);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.btnOK);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.Name = "frmAuthorization";
			this.Text = "Authorization";
			this.Load += new System.EventHandler(this.frmAuthorization_Load);
			this.ResumeLayout(false);

		}
		#endregion

		private void btnCancel_Click(object sender, EventArgs e)
		{
			this.Close();
		}

		private void CheckTextBoxes()
		{
			if ((txtPassword.Text != "") && (txtUserName.Text != ""))
				btnOK.Enabled = true;
			else 
				btnOK.Enabled = false;
		}
		
		private void txtUserName_TextChanged(object sender, EventArgs e)
		{
			this.CheckTextBoxes();		
		}

		private void txtPassword_TextChanged(object sender, EventArgs e)
		{
			this.CheckTextBoxes();
		}
		
		private void btnOK_Click(object sender, EventArgs e)
		{
			this.CheckLogin();
		}

		private void frmAuthorization_Activated(object sender, EventArgs e)
		{
			WindowsIdentity t = WindowsIdentity.GetCurrent();
			this.txtUserName.Text=t.Name.ToString();
			this.txtPassword.Focus();
		}

		private void frmAuthorization_Load(object sender, System.EventArgs e)
		{
		
		}
	
	}
}