using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using SQLDBAD;
using System.IO;

namespace Manager
{
	public class frmFlash : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button btnDetachDB;
		private System.Windows.Forms.Button btnAttachDB;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.OpenFileDialog openFileDialog;
		private System.Windows.Forms.TreeView tvBrowserFoldersAndFiles;
		private System.Windows.Forms.ImageList imageList;
		private System.Windows.Forms.TextBox txtDBAddress;
		private System.ComponentModel.IContainer components;

		private string dbPath = "";
		private System.Windows.Forms.HelpProvider helpProvider1;
		private System.Windows.Forms.Button btnClose;
		private string nodeName = "";

		public frmFlash()
		{
			InitializeComponent();
			
			this.InitDefaultSettings();
			this.LoadTree();
		}

		private void InitDefaultSettings()
		{
			btnAttachDB.Enabled = false;
			btnDetachDB.Enabled = false;

			txtDBAddress.TextChanged += new EventHandler(txtDBAddress_TextChanged);
		}

		private void LoadTree()
		{
			try
			{
				tvBrowserFoldersAndFiles.Nodes.Clear();
			
				string[] drives = Directory.GetLogicalDrives();
			
				//   
				for (int i = 0; i < drives.Length; i++)
				{
					drives[i] = drives[i].Remove(drives[i].Length - 1, 1);
				}

				//  
				foreach (string drive in drives)
				{				
					TreeNode tn = new TreeNode(drive);
				
					tn.ImageIndex = 4;
					tvBrowserFoldersAndFiles.Nodes.Add(tn);				
				}
			
				//    
				for (int i = 1; i < tvBrowserFoldersAndFiles.Nodes.Count; i++)
				{
					tvBrowserFoldersAndFiles.Nodes[i].Nodes.Clear();

					AddDirectories(tvBrowserFoldersAndFiles.Nodes[i]);				
					AddFiles(tvBrowserFoldersAndFiles.Nodes[i]);				
				}
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, ex.Source);
			}
		}
		private void AddDirectories(TreeNode tn)
		{
			try
			{	
				tn.Nodes.Clear();

				string path = tn.FullPath + @"\";

				DirectoryInfo directory = new DirectoryInfo(path);

				DirectoryInfo[] folders = directory.GetDirectories();
				
				foreach (DirectoryInfo folder in folders)
				{
					TreeNode tnFolder = new TreeNode(folder.Name);
					tnFolder.ImageIndex = 0;

					tn.Nodes.Add(tnFolder);
				}
			}
			catch
			{
				return;
			}
		}

		private void AddFiles(TreeNode tn)
		{
			try
			{	
				string path = tn.FullPath;

				DirectoryInfo directory = new DirectoryInfo(path);

				FileInfo[] files = directory.GetFiles();

				foreach (FileInfo file in files)
				{
					if (file.Extension.ToLower() == ".mdf")
					{
						TreeNode tnFile = new TreeNode(file.Name);
						tnFile.ImageIndex = 3;

						tn.Nodes.Add(tnFile); 
					}
				}
			}
			catch
			{
				return;
			}
		}

		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}


		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(frmFlash));
			this.btnDetachDB = new System.Windows.Forms.Button();
			this.btnAttachDB = new System.Windows.Forms.Button();
			this.label2 = new System.Windows.Forms.Label();
			this.openFileDialog = new System.Windows.Forms.OpenFileDialog();
			this.tvBrowserFoldersAndFiles = new System.Windows.Forms.TreeView();
			this.imageList = new System.Windows.Forms.ImageList(this.components);
			this.txtDBAddress = new System.Windows.Forms.TextBox();
			this.helpProvider1 = new System.Windows.Forms.HelpProvider();
			this.btnClose = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// btnDetachDB
			// 
			this.helpProvider1.SetHelpString(this.btnDetachDB, "Detaching database from SqlServer");
			this.btnDetachDB.Location = new System.Drawing.Point(328, 72);
			this.btnDetachDB.Name = "btnDetachDB";
			this.helpProvider1.SetShowHelp(this.btnDetachDB, true);
			this.btnDetachDB.Size = new System.Drawing.Size(80, 23);
			this.btnDetachDB.TabIndex = 3;
			this.btnDetachDB.Text = "Detach ...";
			this.btnDetachDB.Click += new System.EventHandler(this.btnDetachDB_Click);
			// 
			// btnAttachDB
			// 
			this.helpProvider1.SetHelpString(this.btnAttachDB, "Attaching a database to SqlServer");
			this.btnAttachDB.Location = new System.Drawing.Point(328, 40);
			this.btnAttachDB.Name = "btnAttachDB";
			this.helpProvider1.SetShowHelp(this.btnAttachDB, true);
			this.btnAttachDB.Size = new System.Drawing.Size(80, 23);
			this.btnAttachDB.TabIndex = 2;
			this.btnAttachDB.Text = "Attach ...";
			this.btnAttachDB.Click += new System.EventHandler(this.btnAttachDB_Click);
			// 
			// label2
			// 
			this.label2.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(204)));
			this.label2.ForeColor = System.Drawing.SystemColors.Highlight;
			this.label2.Location = new System.Drawing.Point(8, 8);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(312, 24);
			this.label2.TabIndex = 19;
			this.label2.Text = "/   flash / SQL Server";
			// 
			// tvBrowserFoldersAndFiles
			// 
			this.helpProvider1.SetHelpString(this.tvBrowserFoldersAndFiles, "Find database here");
			this.tvBrowserFoldersAndFiles.ImageList = this.imageList;
			this.tvBrowserFoldersAndFiles.Location = new System.Drawing.Point(8, 72);
			this.tvBrowserFoldersAndFiles.Name = "tvBrowserFoldersAndFiles";
			this.tvBrowserFoldersAndFiles.SelectedImageIndex = 2;
			this.helpProvider1.SetShowHelp(this.tvBrowserFoldersAndFiles, true);
			this.tvBrowserFoldersAndFiles.Size = new System.Drawing.Size(304, 296);
			this.tvBrowserFoldersAndFiles.TabIndex = 1;
			this.tvBrowserFoldersAndFiles.AfterSelect += new System.Windows.Forms.TreeViewEventHandler(this.tvBrowserFoldersAndFiles_AfterSelect);
			this.tvBrowserFoldersAndFiles.BeforeSelect += new System.Windows.Forms.TreeViewCancelEventHandler(this.tvBrowserFoldersAndFiles_BeforeSelect);
			this.tvBrowserFoldersAndFiles.BeforeExpand += new System.Windows.Forms.TreeViewCancelEventHandler(this.tvBrowserFoldersAndFiles_BeforeExpand);
			// 
			// imageList
			// 
			this.imageList.ImageSize = new System.Drawing.Size(16, 16);
			this.imageList.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("imageList.ImageStream")));
			this.imageList.TransparentColor = System.Drawing.Color.Transparent;
			// 
			// txtDBAddress
			// 
			this.helpProvider1.SetHelpString(this.txtDBAddress, "Full path to flash-database ");
			this.txtDBAddress.Location = new System.Drawing.Point(8, 40);
			this.txtDBAddress.Name = "txtDBAddress";
			this.txtDBAddress.ReadOnly = true;
			this.helpProvider1.SetShowHelp(this.txtDBAddress, true);
			this.txtDBAddress.Size = new System.Drawing.Size(304, 20);
			this.txtDBAddress.TabIndex = 0;
			this.txtDBAddress.Text = "";
			// 
			// btnClose
			// 
			this.btnClose.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnClose.Location = new System.Drawing.Point(328, 344);
			this.btnClose.Name = "btnClose";
			this.btnClose.Size = new System.Drawing.Size(80, 24);
			this.btnClose.TabIndex = 4;
			this.btnClose.Text = "";
			this.btnClose.Click += new System.EventHandler(this.btnClose_Click);
			// 
			// frmFlash
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnClose;
			this.ClientSize = new System.Drawing.Size(418, 383);
			this.Controls.Add(this.btnClose);
			this.Controls.Add(this.txtDBAddress);
			this.Controls.Add(this.tvBrowserFoldersAndFiles);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.btnDetachDB);
			this.Controls.Add(this.btnAttachDB);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.HelpButton = true;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "frmFlash";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
			this.Text = "Flash";
			this.Load += new System.EventHandler(this.frmFlash_Load);
			this.Activated += new System.EventHandler(this.frmFlash_Load);
			this.ResumeLayout(false);

		}
		#endregion

		private void btnAttachDB_Click(object sender, System.EventArgs e)
		{
			SQLDbManager manager = new SQLDbManager();
			
			try
			{
				FileInfo fi = new FileInfo(dbPath);

				manager.Connect(".");
				manager.AttachDB(fi.FullName);
				manager.Disconnect();

				frmManager.flashAttached = true;
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, ex.Source);
			}
		}

		private void btnDetachDB_Click(object sender, System.EventArgs e)
		{
			SQLDbManager manager = new SQLDbManager();
			
			try
			{		
				FileInfo fi = new FileInfo(nodeName);

				string dbName = fi.Name.Remove(fi.Name.IndexOf("."), 
												fi.Name.Length - fi.Name.IndexOf("."));
				
				manager.Connect(".");
				manager.DetachDB(dbName);
				manager.Disconnect();
				frmManager.flashAttached = false;
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message, ex.Source);
			}			
		}

		private void driveListBox_SelectionChangeCommitted(object sender, System.EventArgs e)
		{
			try
			{
			}
			catch
			{
				return;
			}
		}

		private void tvBrowserFoldersAndFiles_BeforeExpand(object sender, System.Windows.Forms.TreeViewCancelEventArgs e)
		{
			foreach(TreeNode tn in e.Node.Nodes)
			{
				AddDirectories(tn);
				AddFiles(tn);
			}
		}

		private void tvBrowserFoldersAndFiles_BeforeSelect(object sender, System.Windows.Forms.TreeViewCancelEventArgs e)
		{
			
		}

		private void tvBrowserFoldersAndFiles_AfterSelect(object sender, System.Windows.Forms.TreeViewEventArgs e)
		{
			dbPath = e.Node.FullPath;
			nodeName = e.Node.Text;

			txtDBAddress.Text = dbPath.ToLower();

			foreach(TreeNode tn in e.Node.Nodes)
			{
				AddDirectories(tn);
				AddFiles(tn);
			}
		}

		private void frmFlash_Load(object sender, System.EventArgs e)
		{
			txtDBAddress.Focus();
		}

		private void btnClose_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void txtDBAddress_TextChanged(object sender, EventArgs e)
		{			
			FileInfo file = new FileInfo(txtDBAddress.Text);

			if (file.Extension != ".mdf")
			{
				btnAttachDB.Enabled = false;
				btnDetachDB.Enabled = false;

				return;
			}
			
			btnAttachDB.Enabled = true;
			btnDetachDB.Enabled = true;						
		}
	}
}